@@ -6,10 +6,6 @@
 # RH: updated for igraph (from igraph0)
 # sept 23, 2012
 
-if (!isGeneric("clump")) {
-	setGeneric("clump", function(x, ...)
-		standardGeneric("clump"))
-}	
 
 
 .smallClump <- function(x, directions=8) {
@@ -85,7 +81,7 @@ function(x, filename='', directions=8, gaps=TRUE, ...) {
 		xc <- .smallClump(xc, directions) + maxval
 		if (i > 1) {
 			firstrow <- getValues(xc, 1)
-			rc <- na.omit(unique(cbind(lastrow, firstrow)))
+			rc <- stats::na.omit(unique(cbind(lastrow, firstrow)))
 			rcl <- rbind(rcl, rc)
 		}
 		lastrow <- getValues(xc, nrow(xc))
@@ -104,7 +100,7 @@ function(x, filename='', directions=8, gaps=TRUE, ...) {
 	if (nrow(rcl) > 0) {
 		g <- igraph::graph.edgelist(rcl, directed=FALSE)
 		clumps <- igraph::clusters(g)$membership
-		rc <- cbind(V(g), clumps)
+		rc <- cbind(igraph::V(g), clumps)
 		i <- rc[,1] != rc[,2]
 		rc <- rc[i, ,drop=FALSE]
 		if (is.null(datatype)) {
