@@ -180,8 +180,8 @@
 		}
 	}
 	crs <- .getProj(prj, crs)
-	r@crs <- sp::CRS(crs, TRUE) 
-	#r@crs <- sp::CRS(crs, FALSE) 
+	r@crs <- .CRS(crs, TRUE) 
+	#r@crs <- .CRS(crs, FALSE) 
 	# F to avoid warnings about other than WGS84 datums or ellipsoids  
 	
 #  	r@history[[1]] <- mdata
